.onAttach <- function(lib, pkg){
   packageStartupMessage("R/qtlmt is loaded\n")
}
.noGenerics <- TRUE
#.onUnload <- function(libpath){
#   library.dynam.unload("qtlmt", libpath)
#}

